@@ -75,11 +75,10 @@ namespace Hyena
             // TODO: replace with managed conversion to avoid marshalling
             IntPtr path_ptr = GLib.Marshaller.StringToPtrGStrdup (localPath);
 
-#if WIN32
-            IntPtr uri_ptr = g_filename_to_uri_utf8 (path_ptr, IntPtr.Zero, IntPtr.Zero);
-#else
-            IntPtr uri_ptr = g_filename_to_uri (path_ptr, IntPtr.Zero, IntPtr.Zero);
-#endif
+            IntPtr uri_ptr = PlatformDetection.IsWindows
+                ? g_filename_to_uri_utf8 (path_ptr, IntPtr.Zero, IntPtr.Zero)
+                : g_filename_to_uri (path_ptr, IntPtr.Zero, IntPtr.Zero);
+
             GLib.Marshaller.Free (path_ptr);
 
             if (uri_ptr == IntPtr.Zero) {
@@ -96,11 +95,10 @@ namespace Hyena
         {
             // TODO: replace with managed conversion to avoid marshalling
             IntPtr uri_ptr = GLib.Marshaller.StringToPtrGStrdup (uri);
-#if WIN32
-            IntPtr path_ptr = g_filename_from_uri_utf8 (uri_ptr, IntPtr.Zero, IntPtr.Zero);
-#else
-            IntPtr path_ptr = g_filename_from_uri (uri_ptr, IntPtr.Zero, IntPtr.Zero);
-#endif
+
+            IntPtr path_ptr = PlatformDetection.IsWindows
+                ? g_filename_from_uri_utf8 (uri_ptr, IntPtr.Zero, IntPtr.Zero)
+                : g_filename_from_uri (uri_ptr, IntPtr.Zero, IntPtr.Zero);
 
             GLib.Marshaller.Free (uri_ptr);
 
@@ -192,18 +190,16 @@ namespace Hyena
             get { return Scheme == System.Uri.UriSchemeFile; }
         }
 
-#if WIN32
         [DllImport ("libglib-2.0-0.dll")]
         private static extern IntPtr g_filename_to_uri_utf8 (IntPtr filename, IntPtr hostname, IntPtr error);
 
         [DllImport ("libglib-2.0-0.dll")]
         private static extern IntPtr g_filename_from_uri_utf8 (IntPtr uri, IntPtr hostname, IntPtr error);
-#else
+
         [DllImport ("libglib-2.0-0.dll")]
         private static extern IntPtr g_filename_to_uri (IntPtr filename, IntPtr hostname, IntPtr error);
 
         [DllImport ("libglib-2.0-0.dll")]
         private static extern IntPtr g_filename_from_uri (IntPtr uri, IntPtr hostname, IntPtr error);
-#endif
     }
 }
